@@ -12,9 +12,6 @@ function removePending(q, name) {
 class Connector extends EventEmitter {
   constructor(backend, store, services, options = {}) {
     super();
-    if (utils.isIE10) {
-      EventEmitter.call(this); // <=IE10 fix (unable to call parent constructor)
-    }
 
     this.backend = backend;
     this.store = store;
@@ -119,8 +116,8 @@ class Connector extends EventEmitter {
           if (!loaded[l]) loaded[l] = {};
           const loadedKeys = q.loaded[l];
           if (loadedKeys.length) {
-            loadedKeys.forEach((ns) => {
-              if (loaded[l][ns] === undefined) loaded[l][ns] = true;
+            loadedKeys.forEach((n) => {
+              if (loaded[l][n] === undefined) loaded[l][n] = true;
             });
           }
         });
