@@ -1,6 +1,21 @@
 import * as utils from './utils.js';
 import baseLogger from './logger.js';
 
+function deepFindWithDefaults(
+  data,
+  defaultData,
+  key,
+  keySeparator = '.',
+  ignoreJSONStructure = true,
+) {
+  let path = utils.getPathWithDefaults(data, defaultData, key);
+  if (!path && ignoreJSONStructure && typeof key === 'string') {
+    path = utils.deepFind(data, key, keySeparator);
+    if (path === undefined) path = utils.deepFind(defaultData, key, keySeparator);
+  }
+  return path;
+}
+
 class Interpolator {
   constructor(options = {}) {
     this.logger = baseLogger.create('interpolator');
@@ -81,7 +96,13 @@ class Interpolator {
 
     const handleFormat = (key) => {
       if (key.indexOf(this.formatSeparator) < 0) {
-        const path = utils.getPathWithDefaults(data, defaultData, key);
+        const path = deepFindWithDefaults(
+          data,
+          defaultData,
+          key,
+          this.options.keySeparator,
+          this.options.ignoreJSONStructure,
+        );
         return this.alwaysFormat
           ? this.format(path, undefined, lng, { ...options, ...data, interpolationkey: key })
           : path;
@@ -91,11 +112,22 @@ class Interpolator {
       const k = p.shift().trim();
       const f = p.join(this.formatSeparator).trim();
 
-      return this.format(utils.getPathWithDefaults(data, defaultData, k), f, lng, {
-        ...options,
-        ...data,
-        interpolationkey: k,
-      });
+      return this.format(
+        deepFindWithDefaults(
+          data,
+          defaultData,
+          k,
+          this.options.keySeparator,
+          this.options.ignoreJSONStructure,
+        ),
+        f,
+        lng,
+        {
+          ...options,
+          ...data,
+          interpolationkey: k,
+        },
+      );
     };
 
     this.resetRegExp();
@@ -130,7 +162,7 @@ class Interpolator {
           if (typeof missingInterpolationHandler === 'function') {
             const temp = missingInterpolationHandler(str, match, options);
             value = typeof temp === 'string' ? temp : '';
-          } else if (options && options.hasOwnProperty(matchedVar)) {
+          } else if (options && Object.prototype.hasOwnProperty.call(options, matchedVar)) {
             value = ''; // undefined becomes empty string
           } else if (skipOnVariables) {
             value = match[0];
@@ -241,7 +273,7 @@ class Interpolator {
 
       if (doReduce) {
         value = formatters.reduce(
-          /* eslint-disable-line no-loop-func:0 */
+          // eslint-disable-next-line no-loop-func
           (v, f) =>
             this.format(v, f, options.lng, { ...options, interpolationkey: match[1].trim() }),
           value.trim(),
