@@ -8,9 +8,6 @@ const checkedLoadedFor = {};
 class Translator extends EventEmitter {
   constructor(services, options = {}) {
     super();
-    if (utils.isIE10) {
-      EventEmitter.call(this); // <=IE10 fix (unable to call parent constructor)
-    }
 
     utils.copy(
       [
@@ -92,10 +89,11 @@ class Translator extends EventEmitter {
       /* eslint prefer-rest-params: 0 */
       options = this.options.overloadTranslationOptionHandler(arguments);
     }
+    if (typeof options === 'object') options = { ...options };
     if (!options) options = {};
 
     // non valid keys handling
-    if (keys === undefined || keys === null /* || keys === ''*/) return '';
+    if (keys === undefined || keys === null /* || keys === '' */) return '';
     if (!Array.isArray(keys)) keys = [String(keys)];
 
     const returnDetails =
@@ -117,15 +115,27 @@ class Translator extends EventEmitter {
       if (appendNamespaceToCIMode) {
         const nsSeparator = options.nsSeparator || this.options.nsSeparator;
         if (returnDetails) {
-          resolved.res = `${namespace}${nsSeparator}${key}`;
-          return resolved;
+          return {
+            res: `${namespace}${nsSeparator}${key}`,
+            usedKey: key,
+            exactUsedKey: key,
+            usedLng: lng,
+            usedNS: namespace,
+            usedParams: this.getUsedParamsDetails(options),
+          };
         }
         return `${namespace}${nsSeparator}${key}`;
       }
 
       if (returnDetails) {
-        resolved.res = key;
-        return resolved;
+        return {
+          res: key,
+          usedKey: key,
+          exactUsedKey: key,
+          usedLng: lng,
+          usedNS: namespace,
+          usedParams: this.getUsedParamsDetails(options),
+        };
       }
       return key;
     }
@@ -161,6 +171,7 @@ class Translator extends EventEmitter {
           : `key '${key} (${this.language})' returned an object instead of string.`;
         if (returnDetails) {
           resolved.res = r;
+          resolved.usedParams = this.getUsedParamsDetails(options);
           return resolved;
         }
         return r;
@@ -173,7 +184,7 @@ class Translator extends EventEmitter {
         const copy = resTypeIsArray ? [] : {}; // apply child translation on a copy
 
         /* eslint no-restricted-syntax: 0 */
-        let newKeyToUse = resTypeIsArray ? resExactUsedKey : resUsedKey;
+        const newKeyToUse = resTypeIsArray ? resExactUsedKey : resUsedKey;
         for (const m in res) {
           if (Object.prototype.hasOwnProperty.call(res, m)) {
             const deepKey = `${newKeyToUse}${keySeparator}${m}`;
@@ -181,7 +192,7 @@ class Translator extends EventEmitter {
               ...options,
               ...{ joinArrays: false, ns: namespaces },
             });
-            if (copy[m] === deepKey) copy[m] = res[m]; // if nothing found use orginal value as fallback
+            if (copy[m] === deepKey) copy[m] = res[m]; // if nothing found use original value as fallback
           }
         }
         res = copy;
@@ -204,7 +215,14 @@ class Translator extends EventEmitter {
       const defaultValueSuffix = needsPluralHandling
         ? this.pluralResolver.getSuffix(lng, options.count, options)
         : '';
-      const defaultValue = options[`defaultValue${defaultValueSuffix}`] || options.defaultValue;
+      const defaultValueSuffixOrdinalFallback =
+        options.ordinal && needsPluralHandling
+          ? this.pluralResolver.getSuffix(lng, options.count, { ordinal: false })
+          : '';
+      const defaultValue =
+        options[`defaultValue${defaultValueSuffix}`] ||
+        options[`defaultValue${defaultValueSuffixOrdinalFallback}`] ||
+        options.defaultValue;
 
       // fallback value
       if (!this.isValidLookup(res) && hasDefaultValue) {
@@ -314,6 +332,7 @@ class Translator extends EventEmitter {
     // return
     if (returnDetails) {
       resolved.res = res;
+      resolved.usedParams = this.getUsedParamsDetails(options);
       return resolved;
     }
     return res;
@@ -324,7 +343,7 @@ class Translator extends EventEmitter {
       res = this.i18nFormat.parse(
         res,
         { ...this.options.interpolation.defaultVariables, ...options },
-        resolved.usedLng,
+        options.lng || this.language || resolved.usedLng,
         resolved.usedNS,
         resolved.usedKey,
         { resolved },
@@ -361,6 +380,8 @@ class Translator extends EventEmitter {
         const nestAft = na && na.length;
         if (nestBef < nestAft) options.nest = false;
       }
+      if (!options.lng && this.options.compatibilityAPI !== 'v1' && resolved && resolved.res)
+        options.lng = resolved.usedLng;
       if (options.nest !== false)
         res = this.interpolator.nest(
           res,
@@ -395,7 +416,10 @@ class Translator extends EventEmitter {
         res,
         key,
         this.options && this.options.postProcessPassResolved
-          ? { i18nResolved: resolved, ...options }
+          ? {
+              i18nResolved: { ...resolved, usedParams: this.getUsedParamsDetails(options) },
+              ...options,
+            }
           : options,
         this,
       );
@@ -469,10 +493,15 @@ class Translator extends EventEmitter {
             if (needsPluralHandling)
               pluralSuffix = this.pluralResolver.getSuffix(code, options.count, options);
             const zeroSuffix = `${this.options.pluralSeparator}zero`;
-
+            const ordinalPrefix = `${this.options.pluralSeparator}ordinal${this.options.pluralSeparator}`;
             // get key for plural if needed
             if (needsPluralHandling) {
               finalKeys.push(key + pluralSuffix);
+              if (options.ordinal && pluralSuffix.indexOf(ordinalPrefix) === 0) {
+                finalKeys.push(
+                  key + pluralSuffix.replace(ordinalPrefix, this.options.pluralSeparator),
+                );
+              }
               if (needsZeroSuffixLookup) {
                 finalKeys.push(key + zeroSuffix);
               }
@@ -486,6 +515,11 @@ class Translator extends EventEmitter {
               // get key for context + plural if needed
               if (needsPluralHandling) {
                 finalKeys.push(contextKey + pluralSuffix);
+                if (options.ordinal && pluralSuffix.indexOf(ordinalPrefix) === 0) {
+                  finalKeys.push(
+                    contextKey + pluralSuffix.replace(ordinalPrefix, this.options.pluralSeparator),
+                  );
+                }
                 if (needsZeroSuffixLookup) {
                   finalKeys.push(contextKey + zeroSuffix);
                 }
@@ -523,6 +557,47 @@ class Translator extends EventEmitter {
     return this.resourceStore.getResource(code, ns, key, options);
   }
 
+  getUsedParamsDetails(options = {}) {
+    // we need to remember to extend this array whenever new option properties are added
+    const optionsKeys = [
+      'defaultValue',
+      'ordinal',
+      'context',
+      'replace',
+      'lng',
+      'lngs',
+      'fallbackLng',
+      'ns',
+      'keySeparator',
+      'nsSeparator',
+      'returnObjects',
+      'returnDetails',
+      'joinArrays',
+      'postProcess',
+      'interpolation',
+    ];
+
+    const useOptionsReplaceForData = options.replace && typeof options.replace !== 'string';
+    let data = useOptionsReplaceForData ? options.replace : options;
+    if (useOptionsReplaceForData && typeof options.count !== 'undefined') {
+      data.count = options.count;
+    }
+
+    if (this.options.interpolation.defaultVariables) {
+      data = { ...this.options.interpolation.defaultVariables, ...data };
+    }
+
+    // avoid reporting options (execpt count) as usedParams
+    if (!useOptionsReplaceForData) {
+      data = { ...data };
+      for (const key of optionsKeys) {
+        delete data[key];
+      }
+    }
+
+    return data;
+  }
+
   static hasDefaultValue(options) {
     const prefix = 'defaultValue';
 
