@@ -9,7 +9,7 @@ import Formatter from './Formatter.js';
 import BackendConnector from './BackendConnector.js';
 import { get as getDefaults, transformOptions } from './defaults.js';
 import postProcessor from './postProcessor.js';
-import { defer, isIE10 } from './utils.js';
+import { defer } from './utils.js';
 
 function noop() { }
 
@@ -27,9 +27,6 @@ function bindMemberFunctions(inst) {
 class I18n extends EventEmitter {
   constructor(options = {}, callback) {
     super();
-    if (isIE10) {
-      EventEmitter.call(this) // <=IE10 fix (unable to call parent constructor)
-    }
 
     this.options = transformOptions(options);
     this.services = {};
@@ -96,7 +93,6 @@ class I18n extends EventEmitter {
       } else if (typeof Intl !== 'undefined') {
         formatter = Formatter;
       }
-  
 
       const lu = new LanguageUtils(this.options);
       this.store = new ResourceStore(this.options.resources, this.options);
@@ -218,18 +214,20 @@ class I18n extends EventEmitter {
   /* eslint consistent-return: 0 */
   loadResources(language, callback = noop) {
     let usedCallback = callback;
-    let usedLng = typeof language === 'string' ? language : this.language;
+    const usedLng = typeof language === 'string' ? language : this.language;
     if (typeof language === 'function') usedCallback = language;
 
     if (!this.options.resources || this.options.partialBundledLanguages) {
-      if (usedLng && usedLng.toLowerCase() === 'cimode') return usedCallback(); // avoid loading resources for cimode
+      if (usedLng && usedLng.toLowerCase() === 'cimode' && (!this.options.preload || this.options.preload.length === 0)) return usedCallback(); // avoid loading resources for cimode
 
       const toLoad = [];
 
       const append = lng => {
         if (!lng) return;
+        if (lng === 'cimode') return;
         const lngs = this.services.languageUtils.toResolveHierarchy(lng);
         lngs.forEach(l => {
+          if (l === 'cimode') return;
           if (toLoad.indexOf(l) < 0) toLoad.push(l);
         });
       };
@@ -323,7 +321,7 @@ class I18n extends EventEmitter {
     const setLngProps = (l) => {
       this.language = l;
       this.languages = this.services.languageUtils.toResolveHierarchy(l);
-      // find the first language resolved languaged
+      // find the first language resolved language
       this.resolvedLanguage = undefined;
       this.setResolvedLanguage(l);
     };
@@ -393,7 +391,12 @@ class I18n extends EventEmitter {
       options.keyPrefix = options.keyPrefix || keyPrefix || fixedT.keyPrefix;
 
       const keySeparator = this.options.keySeparator || '.';
-      const resultKey = options.keyPrefix ? `${options.keyPrefix}${keySeparator}${key}` : key;
+      let resultKey
+      if (options.keyPrefix && Array.isArray(key)) {
+        resultKey = key.map(k => `${options.keyPrefix}${keySeparator}${k}`);
+      } else {
+        resultKey = options.keyPrefix ? `${options.keyPrefix}${keySeparator}${key}` : key;
+      }
       return this.t(resultKey, options);
     };
     if (typeof lng === 'string') {
@@ -428,7 +431,7 @@ class I18n extends EventEmitter {
       return false;
     }
 
-    const lng = this.resolvedLanguage || this.languages[0];
+    const lng = options.lng || this.resolvedLanguage || this.languages[0];
     const fallbackLng = this.options ? this.options.fallbackLng : false;
     const lastLng = this.languages[this.languages.length - 1];
 
@@ -462,7 +465,7 @@ class I18n extends EventEmitter {
     const deferred = defer();
 
     if (!this.options.ns) {
-      callback && callback();
+      if (callback) callback();
       return Promise.resolve();
     }
     if (typeof ns === 'string') ns = [ns];
@@ -577,9 +580,11 @@ class I18n extends EventEmitter {
       : 'ltr';
   }
 
-  static createInstance = (options = {}, callback) => new I18n(options, callback)
+  static createInstance(options = {}, callback) { return new I18n(options, callback) }
 
   cloneInstance(options = {}, callback = noop) {
+    const forkResourceStore = options.forkResourceStore;
+    if (forkResourceStore) delete options.forkResourceStore;
     const mergedOptions = { ...this.options, ...options, ...{ isClone: true } };
     const clone = new I18n(mergedOptions);
     if ((options.debug !== undefined || options.prefix !== undefined)) {
@@ -593,12 +598,16 @@ class I18n extends EventEmitter {
     clone.services.utils = {
       hasLoadedNamespace: clone.hasLoadedNamespace.bind(clone)
     };
-    clone.translator = new Translator(clone.services, clone.options);
+    if (forkResourceStore) {
+      clone.store = new ResourceStore(this.store.data, mergedOptions);
+      clone.services.resourceStore = clone.store;
+    }
+    clone.translator = new Translator(clone.services, mergedOptions);
     clone.translator.on('*', (event, ...args) => {
       clone.emit(event, ...args);
     });
     clone.init(mergedOptions, callback);
-    clone.translator.options = clone.options; // sync options
+    clone.translator.options = mergedOptions; // sync options
     clone.translator.backendConnector.services.utils = {
       hasLoadedNamespace: clone.hasLoadedNamespace.bind(clone)
     };
