@@ -4,6 +4,7 @@
 import i18next, { Interpolator, Modules, WithT, ResourceStore, Formatter } from 'i18next';
 
 i18next.init();
+const lng = i18next.resolvedLanguage || i18next.language;
 
 const interpolator: Interpolator = i18next.services.interpolator;
 
@@ -25,3 +26,8 @@ formatter!.addCached(
   'test',
   (lng: string | undefined, options: any) => (value: any) => 'formatted',
 );
+
+i18next.on('custom', (arg) => {});
+i18next.emit('custom');
+i18next.emit('custom', { some: 'opt' });
+i18next.emit('custom', { some: 'opt' }, { more: 'stuff' });
